@@ -32,14 +32,6 @@ class SetLedMessage(Message):
         self.set_attributes(priority, address, rtr)
         self.leds = self.byte_to_channels(data[0])
 
-    def to_json(self):
-        """
-        :return: str
-        """
-        json_dict = self.to_json_basic()
-        json_dict["leds_on"] = self.leds
-        return json.dumps(json_dict)
-
     def data_to_binary(self):
         """
         :return: bytes
